Crate embedded_asyncdelay_rp2040

Crate embedded_asyncdelay_rp2040 

License BSD-2-Clause License MIT AppVeyor CI docs.rs crates.io Download numbers dependency status

embedded-asyncdelay-rp2040

A hardware-based, asynchronous delay that can be used with async/await runtimes. The implementation uses one of the underlying hardware alarms (Alarm0 to Alarm3) to trigger an interrupt, which in turn wakes the future’s associated waker.

Configure Hardware Alarm

To use this crate, you must specify which hardware alarm to use for the underlying interrupt scheduler. This is done by setting the appropriate alarm feature. By default, alarm0 is selected.

Waker Slots and Initialization

Since we need to wake the async wakers from the interrupt callback, we need some stack-allocated shared storage. By default, this crate automatically allocates enough space for 16 slots by default. To override this, you must disable the init16 feature, and call the setup_waker_slots! macro once with your desired number of slots manually.

IMPORTANT: If you disable the init16 feature, but don’t call setup_waker_slots!, this will yield a rather cryptic linker error and compilation will fail.

Re-exports

pub extern crate critical_section;
pub extern crate rp2040_hal;

Re-exports

pub use scheduler::DelayScheduler;

Modules

future
A delay future that yields until the given time has elapsed
scheduler
A scheduler to create delay futures